@@ -5,12 +5,14 @@ package org.gcube.portlets.widgets.ckandatapublisherwidget.shared.metadata;
 
 import java.io.Serializable;
 
+import com.google.gwt.user.client.rpc.IsSerializable;
+
 /**
  * To be used when a field must be used to create a group.
  * @see org.gcube.datacatalogue.metadatadiscovery.bean.jaxb.MetadataGrouping
  * @author Costantino Perciante at ISTI-CNR (costantino.perciante@isti.cnr.it)
  */
-public class FieldAsGroup implements Serializable{
+public class FieldAsGroup implements Serializable, IsSerializable{
 
 	private static final long serialVersionUID = 8096886403417944385L;
 	private boolean create;
